@@ -1,4 +1,5 @@
 """Rstcheck configuration functionality."""
+
 from __future__ import annotations
 
 import configparser
@@ -20,7 +21,7 @@ try:
     tomllib_imported = True
 except ModuleNotFoundError:
     if _extras.TOMLI_INSTALLED:  # pragma: no cover
-        import tomli as tomllib  # type: ignore[import,no-redef]
+        import tomli as tomllib  # type: ignore[import-not-found,no-redef]
 
 
 logger = logging.getLogger(__name__)
